/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvSignalVar.h"
#include "HvSignalEnvelope.h"
#include "HvControlBinop.h"
#include "HvSignalLine.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_YzUU237J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YuQGj9Kx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_whd52NTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YuS6lzzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kWcGtjVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3gm2rVJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UHOnhPGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w3CGCuFa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GaxfJF12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tq7ri5QV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b0CuZnAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nDJ3rHFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SI17Z5cu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PDfqijgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9DCjb5bc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SCQx2JxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mOmQZ2V2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pt7BGcim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zHSlAYiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JQY44d9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qAMrcZJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_K06ytC1F_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_882LDN7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BwKQ5hjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bcchM8mJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oNGaek5p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vs1z8Kr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aOCwsrbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_98ONVNgn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_m1aNCc7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IkHIeXsb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_jgaauHfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2AXwKpNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NGNhsMDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GgF9LWmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PGjAhSku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SU0N7hjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wg4WwGnS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OmAW4Feo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_31J8zVMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gap0m4KO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TsKBrQlO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vqdWvSzr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tgfpCLph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PMOCKjkR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_O8VMeOxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dH0s1Pog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xUDFJhpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0STKPWre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xfkNZh6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vjppVeRd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wEVFzDud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JfnLezyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fDg7LzBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wouZ5RNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yJf1ohTK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WnRmHkIL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LTEyXX22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jcNSuczC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ACgWMniS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mSgYuiBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3k8Wyeop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_myBIzWgn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QKmrT3MN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xpgf47aU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OxBNrPy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AyMVLj0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x0ufym6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VNzbOiZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Sx47tpb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o6OzwtsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vH4uftvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LCPTFSXc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_pTW8eBk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B8hd2Vp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8v4Cjcn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pcgKIqAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_osSZEGXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gbfulCH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xciVpCUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_be7I2sfw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NmEJDUN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fXXo38d5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1rGBNEQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VMPffmRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Xms6omyW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gqHowr2S_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_cAIAAoYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WxmpPMBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rbkkAv3Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vtr0bpYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Xc0mnBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GOXca1te_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tMrWMCsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ohI4194z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tX0J7J3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tvfGcDxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LVe946XU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UGyI9idh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BSmHXenY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_arC9chvz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_zJwCZUcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m7UJmMs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qmevK7hl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_obqnJK4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iW3tYKBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iGm8GvRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3p9G7XZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pMB1O4Aj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K55pvSjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3zhwmPhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LkRnZ5Vj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GsFe5I8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xFUzHloO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AXboGeOB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_aCWJtHkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QKrFO9aj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qYk4PN9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3MwQ26Pu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I5oRQ0ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sOoeiUkl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tREFqQpM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UsWL09i1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NNaWfI42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AUKdav6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aEds4p9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6E3ohwc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EWWIBmVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FDLaRdjf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_M4W20Wbr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GkGkIG7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JKlPRRwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kk41bn2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fwrr5ywo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9mEMNXuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3MnheWGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oQN6JznR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GUfTotcv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eIjZIvbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UjFDGOrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5cXcUaGr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QrbfOcA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tXpZYUqR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_fEcrxq99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OUS0N6rl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xosqAeRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z9r8QJ5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KotKlyks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A8fa72Ud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5nE4lADj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jetCk0rq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3gM1ceXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U15cErmW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iImv4UGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dfdsHqcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QENMdQxW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MKBdhdv9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VouWCzJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OcyxWtio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PktapTtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1BQV1jSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OxdsEOxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mfXdsqiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o22QAjgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ys4TpAzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JU4OwQba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QyxQdHbr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lhoKd1IM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cHFHWFBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s17DN19o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_g6XPDHik_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ts5DrmZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TO4JGQBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dUEDzzNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zMWtL2Dj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xxGoUQtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_84tACtll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3LvL1Hr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1KaBbRTs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k1GkhO4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qDmQA3O2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yVlmrlOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MOzDvUHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0qC8A2AX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_h37W38a0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_pmicEo1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lqiLnuSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_el9HRaqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XRVA2bos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cFU3dY7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YzJcMdDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AZG3BTXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LSJXkPxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EzD7SUjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xxVgnEgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jdP5BxoL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Mt7S3TI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lQMTN3gV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N5LCeOgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yhlKBJHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eIcGfANU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZJkga9oA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j5bt7oc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nU9b7QBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HcmFD1Lv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EPXclH4d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zjseA60R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DQTnvRrg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cIVltwMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HLlX6w8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pRLTF7xQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mbxywx9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WQVMRqdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F54ARCej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uDbtQHFk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H5wY99Ij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IybPevhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_99Ygqoot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7O5XbcSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EpRCKgez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rqNJCfAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YjYLF0hA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ed3YdPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OE8L8hoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kLhTDw0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V6ANVUGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KRliVQJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LLLqrVRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_viI2KyHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CfqKM7Nx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9XtmXbqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XYlAhQNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EYFa0y8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_InVUXec3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SvPL7urG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EWlFHwS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MuXiN1tI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T34QIoTD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E9QF3ElJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MR7DJWNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n9cPfurm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GqOzB8N9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qdriSA6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Jthgbuyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_44fSatEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PYtUBXdy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9uM92vrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w2zC2QCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IiIGDw6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OxduJUKo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_wilti4gd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6lRo8FbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V4hM8jgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_j7MS6UMi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ob8WiLKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OtZp4FYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AhOHJe2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JPpc59U0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zXqeZURy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nPDINmSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XFmnw0hC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_to7ZztHQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5aBf3rtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SjcJ1zDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qrN0Q2Q2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TOnL57hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o0D5JYLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gaygh8tR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_9gr0j1h1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_vLyDUOqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gtP5BNq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7hqJ0Hcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XSiC7Gwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u38uwhfq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oDvVw0FD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jxl5Fki6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hwzahJTs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OsWEkMvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ar8jkJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TCuggkit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uzsQcQNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1ftp6y48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KyFYktBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2x8OOra7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_slINcGNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iToTt5aQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KEq7lkDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qzo7lZcM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mn691FPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fDgHgY3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ymH8CcXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GhPC2OtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vLDfgbfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KHJlJTpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WwnHA2Kh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VKwAyaIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FhJ0Qozg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QPTl9Hit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QkxIgBAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BjvvMxw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NQIH59JX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_VztWVOio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZBUuR6V0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n9WCUidi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ntiKuF1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AIqAB6mM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hW4Sau0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ynepjaVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OfCnckxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OuNKKiQf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_OxI1TI52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9ww90vCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oLNwIOtQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A1VHgi2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EPRsItcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1sCQYddA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HN7lyorD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WoF75CJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5JY5smOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b2aB4zfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QwfKYnSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_L4wKfEnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oMT6Qy0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8qkPkpSm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Qsbgjiys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BKmrwCEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1wI0xJRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fhm5HmDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B9liiY57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7QLERxns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m96cyYk4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ntat2xja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XUkmV9ve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jy29Zv3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9L6xgLK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ws1XUg5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CFxktKvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rk6FFprX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_81NVn0M2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V8DeXW3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xPi22G6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kQkflueG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_52QBWTVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Eo0KmaMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DWZrmV4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rdHkoP00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3uLYTKCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9elH8rwq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gfWntK8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_31TZB8qr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FFp4tXSd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7aCIYhYp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_4mnQ4IAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wQI5SBXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XMy0qshK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YdXcm8rq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VY5Prad9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cwqXcaZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UkUribkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dUl5elbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dTeXj6kH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qk2YzuYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AeszVYNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_D8Ll39oQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vbn1Nvr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2CmoJrCm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_zOlBxChH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GmgMX0Kp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_avgPL1fP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_shkMXloz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C986f4pc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DBK2Gl4A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MMhiIXsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FNAzlPJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FLZmSveJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YaidrOlW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oFXPhejo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VraYkebg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AwkblwH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_B1O3YcWA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7GPcIxp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oofJYv03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_procALAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_apXYYKzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v025mXUZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SIYJXzQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KMIBgn4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UlUIy7Ia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s723vQmW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6fXPsCYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4mfUmv7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Bw51xJJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zzUmuSuc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q6GZI7Rz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_17qfO8iE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mcuIxj4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LyDX0S21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q9d9pTTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AvTAMSAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SmlwWnD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PefsoUG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z98OdDvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PREA8BL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q0wL4ITf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Msgc8qaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rXvSAh4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vJEtd2sU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_i8UGMHF5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_n1azfGmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_baRrkqkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FXXItN5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eO7RyBAr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Exxq16A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LhJY8yGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YplD3GRm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0AeLLWfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qGx943fX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SwLrJS8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WORaUgtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_10hXCoW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aQPw6L9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3zkxI4i4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_MHuvYPB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dLKqtkr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q4BceeT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6KS8j4TN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0nUCriYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y6on1J1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4PeSnUcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4pcNaPit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UNC5lWIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XKtppnk4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yknwF28C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ryPPdVNv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XLbHdmwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5eoxYUA4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RDHuCMLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1TFFuYl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h03qHrXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KXI7luis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dMVXGkd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CiVL0wnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ECuXHYTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FWLrBIjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VW7KWjm9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pb4UFj4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iKk3r2B8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bii7eccZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tAuePGnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bVKHk7Cb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_B5ZsRXho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rtz2NL05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z3jKaUYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U57JK18M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KFW9MULl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eLze4t8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ve3luNKL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YqS5GscR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aU6ginMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8kD9dBdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_auAIrPEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WDwUW8O4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dc91boyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_koiDQZY3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ngUxY8gn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x15nixc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kblI8Onj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oUqiTebN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_as6Ynfps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CsxTLSxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7sV1i4DF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RYmQ6Msb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bZziNaBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BivMa4Dp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U5jP7tqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YQo18tUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u83kU1Ce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t9a2MflL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PYeusPEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FF9PYWKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BXUmRvTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0k7Zng5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VU2WPSCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_41te33XZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eVUY3NZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HmfjdDwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DxXPNIm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2yYHGCLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m78zhSE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LVXqByex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7CQD4D3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6Kt5O8ld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4VBJeJjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mTGR9PLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QOeICj4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SrWgeEEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YCefY2k5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z38HzE8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oZcZt9JV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xBDccXc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NPwH72hW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w4FU6Ska_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2pPv2t84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ws5ddfRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Ss3zctu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NMXw0IEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gmimQIL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8fhChKhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TuC12kpY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AwO2pZPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Jhmflrg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lc9SoAjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BOXsuQr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fbzBo2aU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gvo7xFRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2JD9afWZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jHhJzaIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MYTTBOqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CktyFJf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vsrh8MlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KcJkE1ZW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_0cONtAfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9MQeIf7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jhvXmPQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0IlBykEs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_He4a7qya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s3hHEIiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hb4sXWyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mb3N3jXP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7eaPUv04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DNQMiX1S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IDeDQISI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LIsbeuUr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1OuaXGwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9dTgqEwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_evm63l4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Fw4Scv9R_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DRYq3RA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8zqBy3Cn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iLOvQCGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hK9wRA5O_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_nltQ07IJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4F9m8kKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SFbrZ4Xu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HnlIQOLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A7W0Rkxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nQSLrJ9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_zWCxrp3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_7LOlVo3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NsTLVJXj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZVevRRvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_STzsb2BX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gUFVhQtY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FJ5Y9kmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lckv2JDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WkAQ7TVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CQ6H7la4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7shYsaoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wLC95sg1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HCl43DYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NCOQYdiB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bfKyu2jl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_p9XYXcDS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jYaEaF3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a5NKn76p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_h933D0Eq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PYMhIxmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6sqec6R8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lwKtyTzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0IvROCEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MzRcqcvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bHEIp5Lx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TRPJVmDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eFoYHzBc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P2UT2fV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5XEyRT2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GktmkA81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AX4kDfG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zogENK0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tNUcYXSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VO4sxoxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L7ezZcnM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j3cRgf8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pgVjYuRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FRLXmH9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c3w0PtPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iNh4ci8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LK0xj7oe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YfKCxwBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ghMVfrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RVTTmsB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sBqJRjDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OOmskGmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GqFCp6XC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GSk4so9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jffgovOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x8xOfVAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3FUJqv01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bNTWSz3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_quAUAL6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Yqe2Cf41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oe0vSwHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XgpreLLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n9WvcjhW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OZqUEmXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bNkcI8qc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jYLtuA4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pliQlRq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BnvQJyR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UGxOhu9m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rWiuYMQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iH8AeHxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3uHq0nJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sWNf9Xup_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_3sjIzpr4;
  SignalLine sLine_eCNUsoJ0;
  SignalLine sLine_wnUBfvYG;
  SignalLine sLine_ishI1gPi;
  SignalLine sLine_fFF6wSdp;
  SignalLine sLine_G0tln4XA;
  SignalLine sLine_OWwE4qbb;
  SignalLine sLine_raZvvW9o;
  SignalLine sLine_58QEIvpx;
  SignalLine sLine_doflGaew;
  SignalLine sLine_vQ3qLIBE;
  SignalLine sLine_QqgroNRZ;
  SignalEnvelope sEnv_9gr0j1h1;
  SignalEnvelope sEnv_vLyDUOqV;
  SignalLine sLine_L8yYLnq8;
  SignalLine sLine_T2oYDfrU;
  SignalLine sLine_GQmLZRGZ;
  SignalLine sLine_kqBuZREP;
  SignalLine sLine_iknEXkul;
  SignalLine sLine_FaRx2ZOb;
  SignalLine sLine_iGWpmTX6;
  SignalLine sLine_1EuQrMyW;
  SignalLine sLine_nVZTVLz7;
  SignalLine sLine_DwfYmObS;
  SignalLine sLine_h606NhuY;
  SignalLine sLine_NtyfU5bY;
  SignalLine sLine_2jlbMQpQ;
  SignalLine sLine_3jDLoquP;
  SignalLine sLine_CNRF5SMp;
  SignalLine sLine_v9wfl2CI;
  SignalLine sLine_kOCgqA2u;
  SignalLine sLine_1Bj9nx5T;
  SignalEnvelope sEnv_zWCxrp3f;
  SignalEnvelope sEnv_7LOlVo3c;
  SignalLine sLine_Dwleamw2;
  SignalLine sLine_xDXGHvZ4;
  SignalLine sLine_FcYiKPZ8;
  SignalLine sLine_WpbUbgIi;
  SignalLine sLine_3AHwNz2U;
  SignalLine sLine_HqUm03ih;
  SignalLine sLine_q9NEY9QL;
  SignalLine sLine_uhNS3O2d;
  ControlVar cVar_YzUU237J;
  ControlBinop cBinop_YuQGj9Kx;
  ControlBinop cBinop_whd52NTu;
  ControlBinop cBinop_YuS6lzzH;
  ControlBinop cBinop_kWcGtjVr;
  ControlBinop cBinop_w3CGCuFa;
  ControlBinop cBinop_Tq7ri5QV;
  ControlBinop cBinop_b0CuZnAJ;
  ControlBinop cBinop_nDJ3rHFt;
  ControlVar cVar_SI17Z5cu;
  ControlVar cVar_PDfqijgf;
  ControlVar cVar_9DCjb5bc;
  ControlVar cVar_SCQx2JxB;
  ControlVar cVar_mOmQZ2V2;
  ControlBinop cBinop_Pt7BGcim;
  ControlVar cVar_JQY44d9x;
  ControlVar cVar_qAMrcZJH;
  ControlIf cIf_98ONVNgn;
  ControlIf cIf_m1aNCc7C;
  ControlDelay cDelay_jgaauHfr;
  ControlBinop cBinop_GgF9LWmS;
  ControlBinop cBinop_PGjAhSku;
  ControlIf cIf_vqdWvSzr;
  ControlIf cIf_tgfpCLph;
  ControlDelay cDelay_O8VMeOxt;
  ControlBinop cBinop_0STKPWre;
  ControlBinop cBinop_xfkNZh6e;
  ControlIf cIf_WnRmHkIL;
  ControlIf cIf_LTEyXX22;
  ControlDelay cDelay_ACgWMniS;
  ControlBinop cBinop_myBIzWgn;
  ControlBinop cBinop_QKmrT3MN;
  ControlIf cIf_o6OzwtsT;
  ControlIf cIf_vH4uftvg;
  ControlDelay cDelay_pTW8eBk1;
  ControlBinop cBinop_pcgKIqAN;
  ControlBinop cBinop_osSZEGXl;
  ControlIf cIf_VMPffmRJ;
  ControlIf cIf_Xms6omyW;
  ControlDelay cDelay_cAIAAoYB;
  ControlBinop cBinop_vtr0bpYC;
  ControlBinop cBinop_1Xc0mnBE;
  ControlIf cIf_UGyI9idh;
  ControlIf cIf_BSmHXenY;
  ControlDelay cDelay_zJwCZUcs;
  ControlBinop cBinop_obqnJK4i;
  ControlBinop cBinop_iW3tYKBW;
  ControlIf cIf_GsFe5I8x;
  ControlIf cIf_xFUzHloO;
  ControlDelay cDelay_aCWJtHkR;
  ControlBinop cBinop_3MwQ26Pu;
  ControlBinop cBinop_I5oRQ0ih;
  ControlIf cIf_6E3ohwc6;
  ControlIf cIf_EWWIBmVe;
  ControlDelay cDelay_M4W20Wbr;
  ControlBinop cBinop_Kk41bn2S;
  ControlBinop cBinop_fwrr5ywo;
  ControlIf cIf_5cXcUaGr;
  ControlIf cIf_QrbfOcA4;
  ControlDelay cDelay_fEcrxq99;
  ControlBinop cBinop_z9r8QJ5I;
  ControlBinop cBinop_KotKlyks;
  ControlIf cIf_dfdsHqcK;
  ControlIf cIf_QENMdQxW;
  ControlDelay cDelay_VouWCzJs;
  ControlBinop cBinop_1BQV1jSn;
  ControlBinop cBinop_OxdsEOxe;
  ControlIf cIf_cHFHWFBW;
  ControlIf cIf_s17DN19o;
  ControlDelay cDelay_ts5DrmZA;
  ControlBinop cBinop_zMWtL2Dj;
  ControlBinop cBinop_xxGoUQtH;
  ControlIf cIf_MOzDvUHu;
  ControlIf cIf_0qC8A2AX;
  ControlDelay cDelay_pmicEo1c;
  ControlBinop cBinop_XRVA2bos;
  ControlBinop cBinop_cFU3dY7C;
  SignalVarf sVarf_CzNkM2Uv;
  SignalVarf sVarf_aOS4qwsz;
  SignalVarf sVarf_rGxdkI0s;
  SignalVarf sVarf_i8MnBXhy;
  SignalVarf sVarf_eq4Qf41g;
  SignalVarf sVarf_pMVu6uR5;
  SignalVarf sVarf_lY5BOI3L;
  SignalVarf sVarf_rpY57DEc;
  ControlVar cVar_n9cPfurm;
  ControlSlice cSlice_qdriSA6I;
  ControlVar cVar_Jthgbuyr;
  ControlSlice cSlice_9uM92vrd;
  ControlVar cVar_w2zC2QCG;
  ControlSlice cSlice_wilti4gd;
  ControlVar cVar_6lRo8FbN;
  ControlSlice cSlice_ob8WiLKT;
  ControlVar cVar_OtZp4FYc;
  ControlSlice cSlice_zXqeZURy;
  ControlVar cVar_nPDINmSP;
  ControlDelay cDelay_5aBf3rtt;
  ControlVar cVar_TOnL57hy;
  ControlIf cIf_o0D5JYLa;
  ControlIf cIf_gaygh8tR;
  ControlBinop cBinop_gtP5BNq2;
  ControlBinop cBinop_XSiC7Gwg;
  ControlBinop cBinop_u38uwhfq;
  ControlBinop cBinop_hwzahJTs;
  ControlBinop cBinop_8ar8jkJu;
  ControlSlice cSlice_slINcGNI;
  ControlVar cVar_iToTt5aQ;
  SignalVarf sVarf_UTvU3obp;
  SignalVarf sVarf_eog9agXk;
  SignalVarf sVarf_blylx15h;
  SignalVarf sVarf_jElP9FdC;
  SignalVarf sVarf_wCc4Sm45;
  SignalVarf sVarf_xPgze1ER;
  ControlBinop cBinop_fDgHgY3d;
  ControlBinop cBinop_FhJ0Qozg;
  ControlVar cVar_QkxIgBAV;
  ControlVar cVar_BjvvMxw8;
  ControlIf cIf_ynepjaVo;
  ControlIf cIf_OfCnckxn;
  ControlDelay cDelay_OxI1TI52;
  ControlBinop cBinop_A1VHgi2U;
  ControlBinop cBinop_EPRsItcT;
  ControlIf cIf_L4wKfEnP;
  ControlIf cIf_oMT6Qy0n;
  ControlDelay cDelay_Qsbgjiys;
  ControlBinop cBinop_Fhm5HmDR;
  ControlBinop cBinop_B9liiY57;
  ControlIf cIf_Ws1XUg5E;
  ControlIf cIf_CFxktKvY;
  ControlDelay cDelay_81NVn0M2;
  ControlBinop cBinop_kQkflueG;
  ControlBinop cBinop_52QBWTVT;
  ControlIf cIf_31TZB8qr;
  ControlIf cIf_FFp4tXSd;
  ControlDelay cDelay_4mnQ4IAd;
  ControlBinop cBinop_YdXcm8rq;
  ControlBinop cBinop_VY5Prad9;
  ControlIf cIf_D8Ll39oQ;
  ControlIf cIf_vbn1Nvr7;
  ControlDelay cDelay_zOlBxChH;
  ControlBinop cBinop_shkMXloz;
  ControlBinop cBinop_C986f4pc;
  ControlIf cIf_VraYkebg;
  ControlIf cIf_AwkblwH3;
  ControlDelay cDelay_7GPcIxp2;
  ControlBinop cBinop_apXYYKzm;
  ControlBinop cBinop_v025mXUZ;
  ControlIf cIf_Bw51xJJw;
  ControlIf cIf_zzUmuSuc;
  ControlDelay cDelay_17qfO8iE;
  ControlBinop cBinop_q9d9pTTp;
  ControlBinop cBinop_AvTAMSAP;
  ControlIf cIf_rXvSAh4F;
  ControlIf cIf_vJEtd2sU;
  ControlDelay cDelay_n1azfGmq;
  ControlBinop cBinop_eO7RyBAr;
  ControlBinop cBinop_5Exxq16A;
  ControlIf cIf_10hXCoW8;
  ControlIf cIf_aQPw6L9E;
  ControlDelay cDelay_MHuvYPB3;
  ControlBinop cBinop_6KS8j4TN;
  ControlBinop cBinop_0nUCriYF;
  ControlIf cIf_ryPPdVNv;
  ControlIf cIf_XLbHdmwV;
  ControlDelay cDelay_RDHuCMLa;
  ControlBinop cBinop_KXI7luis;
  ControlBinop cBinop_dMVXGkd4;
  ControlIf cIf_bii7eccZ;
  ControlIf cIf_tAuePGnv;
  ControlDelay cDelay_B5ZsRXho;
  ControlBinop cBinop_U57JK18M;
  ControlBinop cBinop_KFW9MULl;
  ControlIf cIf_WDwUW8O4;
  ControlIf cIf_dc91boyt;
  ControlDelay cDelay_ngUxY8gn;
  ControlBinop cBinop_oUqiTebN;
  ControlBinop cBinop_as6Ynfps;
  SignalVarf sVarf_8BjOS2wi;
  SignalVarf sVarf_pxDUPLQy;
  SignalVarf sVarf_s23omfUJ;
  SignalVarf sVarf_dABOo7FA;
  SignalVarf sVarf_7mZ4V3aI;
  SignalVarf sVarf_acGQmIOZ;
  SignalVarf sVarf_28yt0Ppa;
  SignalVarf sVarf_HiILVQEo;
  ControlVar cVar_vsrh8MlR;
  ControlSlice cSlice_0cONtAfW;
  ControlVar cVar_9MQeIf7d;
  ControlSlice cSlice_He4a7qya;
  ControlVar cVar_s3hHEIiP;
  ControlSlice cSlice_7eaPUv04;
  ControlVar cVar_DNQMiX1S;
  ControlSlice cSlice_1OuaXGwM;
  ControlVar cVar_9dTgqEwF;
  ControlSlice cSlice_DRYq3RA5;
  ControlVar cVar_8zqBy3Cn;
  ControlDelay cDelay_nltQ07IJ;
  ControlVar cVar_HnlIQOLW;
  ControlIf cIf_A7W0Rkxw;
  ControlIf cIf_nQSLrJ9a;
  ControlBinop cBinop_NsTLVJXj;
  ControlBinop cBinop_STzsb2BX;
  ControlBinop cBinop_gUFVhQtY;
  ControlBinop cBinop_WkAQ7TVm;
  ControlBinop cBinop_7shYsaoB;
  ControlSlice cSlice_jYaEaF3K;
  ControlVar cVar_a5NKn76p;
  SignalVarf sVarf_EcSP8n4B;
  SignalVarf sVarf_iK3NPcBa;
  SignalVarf sVarf_TumcM0tN;
  SignalVarf sVarf_QgQ6ZKaA;
  SignalVarf sVarf_dfM24tPD;
  SignalVarf sVarf_uLpiYzYQ;
  ControlBinop cBinop_lwKtyTzK;
  ControlBinop cBinop_5XEyRT2W;
  ControlVar cVar_AX4kDfG9;
  SignalVarf sVarf_R2041KNk;
  SignalVarf sVarf_ZIsWwHFp;
  SignalVarf sVarf_Ex7myXRr;
  SignalVarf sVarf_UQQpvux3;
  ControlBinop cBinop_pgVjYuRp;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
