/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_3sjIzpr4);
  numBytes += sLine_init(&sLine_eCNUsoJ0);
  numBytes += sLine_init(&sLine_wnUBfvYG);
  numBytes += sLine_init(&sLine_ishI1gPi);
  numBytes += sLine_init(&sLine_fFF6wSdp);
  numBytes += sLine_init(&sLine_G0tln4XA);
  numBytes += sLine_init(&sLine_OWwE4qbb);
  numBytes += sLine_init(&sLine_raZvvW9o);
  numBytes += sLine_init(&sLine_58QEIvpx);
  numBytes += sLine_init(&sLine_doflGaew);
  numBytes += sLine_init(&sLine_vQ3qLIBE);
  numBytes += sLine_init(&sLine_QqgroNRZ);
  numBytes += sEnv_init(&sEnv_9gr0j1h1, 512, 256);
  numBytes += sEnv_init(&sEnv_vLyDUOqV, 512, 256);
  numBytes += sLine_init(&sLine_L8yYLnq8);
  numBytes += sLine_init(&sLine_T2oYDfrU);
  numBytes += sLine_init(&sLine_GQmLZRGZ);
  numBytes += sLine_init(&sLine_kqBuZREP);
  numBytes += sLine_init(&sLine_iknEXkul);
  numBytes += sLine_init(&sLine_FaRx2ZOb);
  numBytes += sLine_init(&sLine_iGWpmTX6);
  numBytes += sLine_init(&sLine_1EuQrMyW);
  numBytes += sLine_init(&sLine_nVZTVLz7);
  numBytes += sLine_init(&sLine_DwfYmObS);
  numBytes += sLine_init(&sLine_h606NhuY);
  numBytes += sLine_init(&sLine_NtyfU5bY);
  numBytes += sLine_init(&sLine_2jlbMQpQ);
  numBytes += sLine_init(&sLine_3jDLoquP);
  numBytes += sLine_init(&sLine_CNRF5SMp);
  numBytes += sLine_init(&sLine_v9wfl2CI);
  numBytes += sLine_init(&sLine_kOCgqA2u);
  numBytes += sLine_init(&sLine_1Bj9nx5T);
  numBytes += sEnv_init(&sEnv_zWCxrp3f, 512, 256);
  numBytes += sEnv_init(&sEnv_7LOlVo3c, 512, 256);
  numBytes += sLine_init(&sLine_Dwleamw2);
  numBytes += sLine_init(&sLine_xDXGHvZ4);
  numBytes += sLine_init(&sLine_FcYiKPZ8);
  numBytes += sLine_init(&sLine_WpbUbgIi);
  numBytes += sLine_init(&sLine_3AHwNz2U);
  numBytes += sLine_init(&sLine_HqUm03ih);
  numBytes += sLine_init(&sLine_q9NEY9QL);
  numBytes += sLine_init(&sLine_uhNS3O2d);
  numBytes += cVar_init_f(&cVar_YzUU237J, 0.0f);
  numBytes += cVar_init_f(&cVar_SI17Z5cu, 0.0f);
  numBytes += cVar_init_f(&cVar_PDfqijgf, 0.0f);
  numBytes += cVar_init_f(&cVar_9DCjb5bc, 0.0f);
  numBytes += cVar_init_f(&cVar_SCQx2JxB, 0.0f);
  numBytes += cVar_init_f(&cVar_mOmQZ2V2, 1.0f);
  numBytes += cVar_init_f(&cVar_JQY44d9x, 0.0f);
  numBytes += cVar_init_f(&cVar_qAMrcZJH, 0.0f);
  numBytes += cIf_init(&cIf_98ONVNgn, false);
  numBytes += cIf_init(&cIf_m1aNCc7C, false);
  numBytes += cDelay_init(this, &cDelay_jgaauHfr, 10.0f);
  numBytes += cIf_init(&cIf_vqdWvSzr, false);
  numBytes += cIf_init(&cIf_tgfpCLph, false);
  numBytes += cDelay_init(this, &cDelay_O8VMeOxt, 10.0f);
  numBytes += cIf_init(&cIf_WnRmHkIL, false);
  numBytes += cIf_init(&cIf_LTEyXX22, false);
  numBytes += cDelay_init(this, &cDelay_ACgWMniS, 10.0f);
  numBytes += cIf_init(&cIf_o6OzwtsT, false);
  numBytes += cIf_init(&cIf_vH4uftvg, false);
  numBytes += cDelay_init(this, &cDelay_pTW8eBk1, 10.0f);
  numBytes += cIf_init(&cIf_VMPffmRJ, false);
  numBytes += cIf_init(&cIf_Xms6omyW, false);
  numBytes += cDelay_init(this, &cDelay_cAIAAoYB, 10.0f);
  numBytes += cIf_init(&cIf_UGyI9idh, false);
  numBytes += cIf_init(&cIf_BSmHXenY, false);
  numBytes += cDelay_init(this, &cDelay_zJwCZUcs, 10.0f);
  numBytes += cIf_init(&cIf_GsFe5I8x, false);
  numBytes += cIf_init(&cIf_xFUzHloO, false);
  numBytes += cDelay_init(this, &cDelay_aCWJtHkR, 10.0f);
  numBytes += cIf_init(&cIf_6E3ohwc6, false);
  numBytes += cIf_init(&cIf_EWWIBmVe, false);
  numBytes += cDelay_init(this, &cDelay_M4W20Wbr, 10.0f);
  numBytes += cIf_init(&cIf_5cXcUaGr, false);
  numBytes += cIf_init(&cIf_QrbfOcA4, false);
  numBytes += cDelay_init(this, &cDelay_fEcrxq99, 10.0f);
  numBytes += cIf_init(&cIf_dfdsHqcK, false);
  numBytes += cIf_init(&cIf_QENMdQxW, false);
  numBytes += cDelay_init(this, &cDelay_VouWCzJs, 10.0f);
  numBytes += cIf_init(&cIf_cHFHWFBW, false);
  numBytes += cIf_init(&cIf_s17DN19o, false);
  numBytes += cDelay_init(this, &cDelay_ts5DrmZA, 10.0f);
  numBytes += cIf_init(&cIf_MOzDvUHu, false);
  numBytes += cIf_init(&cIf_0qC8A2AX, false);
  numBytes += cDelay_init(this, &cDelay_pmicEo1c, 10.0f);
  numBytes += sVarf_init(&sVarf_CzNkM2Uv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aOS4qwsz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rGxdkI0s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i8MnBXhy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eq4Qf41g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pMVu6uR5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lY5BOI3L, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rpY57DEc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_n9cPfurm, 0.0f);
  numBytes += cSlice_init(&cSlice_qdriSA6I, 1, -1);
  numBytes += cVar_init_f(&cVar_Jthgbuyr, 1.0f);
  numBytes += cSlice_init(&cSlice_9uM92vrd, 1, -1);
  numBytes += cVar_init_f(&cVar_w2zC2QCG, 0.0f);
  numBytes += cSlice_init(&cSlice_wilti4gd, 1, -1);
  numBytes += cVar_init_f(&cVar_6lRo8FbN, 512.0f);
  numBytes += cSlice_init(&cSlice_ob8WiLKT, 1, -1);
  numBytes += cVar_init_f(&cVar_OtZp4FYc, 1.0f);
  numBytes += cSlice_init(&cSlice_zXqeZURy, 1, -1);
  numBytes += cVar_init_f(&cVar_nPDINmSP, 1.0f);
  numBytes += cDelay_init(this, &cDelay_5aBf3rtt, 20.0f);
  numBytes += cVar_init_f(&cVar_TOnL57hy, 0.0f);
  numBytes += cIf_init(&cIf_o0D5JYLa, false);
  numBytes += cIf_init(&cIf_gaygh8tR, false);
  numBytes += cBinop_init(&cBinop_gtP5BNq2, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_slINcGNI, 1, -1);
  numBytes += cVar_init_f(&cVar_iToTt5aQ, 0.0f);
  numBytes += sVarf_init(&sVarf_UTvU3obp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eog9agXk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_blylx15h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jElP9FdC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wCc4Sm45, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xPgze1ER, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_QkxIgBAV, 0.0f);
  numBytes += cVar_init_f(&cVar_BjvvMxw8, 0.0f);
  numBytes += cIf_init(&cIf_ynepjaVo, false);
  numBytes += cIf_init(&cIf_OfCnckxn, false);
  numBytes += cDelay_init(this, &cDelay_OxI1TI52, 10.0f);
  numBytes += cIf_init(&cIf_L4wKfEnP, false);
  numBytes += cIf_init(&cIf_oMT6Qy0n, false);
  numBytes += cDelay_init(this, &cDelay_Qsbgjiys, 10.0f);
  numBytes += cIf_init(&cIf_Ws1XUg5E, false);
  numBytes += cIf_init(&cIf_CFxktKvY, false);
  numBytes += cDelay_init(this, &cDelay_81NVn0M2, 10.0f);
  numBytes += cIf_init(&cIf_31TZB8qr, false);
  numBytes += cIf_init(&cIf_FFp4tXSd, false);
  numBytes += cDelay_init(this, &cDelay_4mnQ4IAd, 10.0f);
  numBytes += cIf_init(&cIf_D8Ll39oQ, false);
  numBytes += cIf_init(&cIf_vbn1Nvr7, false);
  numBytes += cDelay_init(this, &cDelay_zOlBxChH, 10.0f);
  numBytes += cIf_init(&cIf_VraYkebg, false);
  numBytes += cIf_init(&cIf_AwkblwH3, false);
  numBytes += cDelay_init(this, &cDelay_7GPcIxp2, 10.0f);
  numBytes += cIf_init(&cIf_Bw51xJJw, false);
  numBytes += cIf_init(&cIf_zzUmuSuc, false);
  numBytes += cDelay_init(this, &cDelay_17qfO8iE, 10.0f);
  numBytes += cIf_init(&cIf_rXvSAh4F, false);
  numBytes += cIf_init(&cIf_vJEtd2sU, false);
  numBytes += cDelay_init(this, &cDelay_n1azfGmq, 10.0f);
  numBytes += cIf_init(&cIf_10hXCoW8, false);
  numBytes += cIf_init(&cIf_aQPw6L9E, false);
  numBytes += cDelay_init(this, &cDelay_MHuvYPB3, 10.0f);
  numBytes += cIf_init(&cIf_ryPPdVNv, false);
  numBytes += cIf_init(&cIf_XLbHdmwV, false);
  numBytes += cDelay_init(this, &cDelay_RDHuCMLa, 10.0f);
  numBytes += cIf_init(&cIf_bii7eccZ, false);
  numBytes += cIf_init(&cIf_tAuePGnv, false);
  numBytes += cDelay_init(this, &cDelay_B5ZsRXho, 10.0f);
  numBytes += cIf_init(&cIf_WDwUW8O4, false);
  numBytes += cIf_init(&cIf_dc91boyt, false);
  numBytes += cDelay_init(this, &cDelay_ngUxY8gn, 10.0f);
  numBytes += sVarf_init(&sVarf_8BjOS2wi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pxDUPLQy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s23omfUJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dABOo7FA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7mZ4V3aI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_acGQmIOZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_28yt0Ppa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HiILVQEo, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vsrh8MlR, 0.0f);
  numBytes += cSlice_init(&cSlice_0cONtAfW, 1, -1);
  numBytes += cVar_init_f(&cVar_9MQeIf7d, 1.0f);
  numBytes += cSlice_init(&cSlice_He4a7qya, 1, -1);
  numBytes += cVar_init_f(&cVar_s3hHEIiP, 0.0f);
  numBytes += cSlice_init(&cSlice_7eaPUv04, 1, -1);
  numBytes += cVar_init_f(&cVar_DNQMiX1S, 512.0f);
  numBytes += cSlice_init(&cSlice_1OuaXGwM, 1, -1);
  numBytes += cVar_init_f(&cVar_9dTgqEwF, 1.0f);
  numBytes += cSlice_init(&cSlice_DRYq3RA5, 1, -1);
  numBytes += cVar_init_f(&cVar_8zqBy3Cn, 1.0f);
  numBytes += cDelay_init(this, &cDelay_nltQ07IJ, 20.0f);
  numBytes += cVar_init_f(&cVar_HnlIQOLW, 0.0f);
  numBytes += cIf_init(&cIf_A7W0Rkxw, false);
  numBytes += cIf_init(&cIf_nQSLrJ9a, false);
  numBytes += cBinop_init(&cBinop_NsTLVJXj, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_jYaEaF3K, 1, -1);
  numBytes += cVar_init_f(&cVar_a5NKn76p, 0.0f);
  numBytes += sVarf_init(&sVarf_EcSP8n4B, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iK3NPcBa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TumcM0tN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QgQ6ZKaA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dfM24tPD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uLpiYzYQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AX4kDfG9, 0.0f);
  numBytes += sVarf_init(&sVarf_R2041KNk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZIsWwHFp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ex7myXRr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UQQpvux3, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_9gr0j1h1);
  sEnv_free(&sEnv_vLyDUOqV);
  sEnv_free(&sEnv_zWCxrp3f);
  sEnv_free(&sEnv_7LOlVo3c);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x8xOfVAy_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_quAUAL6P_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sWNf9Xup_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bNTWSz3w_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jffgovOM_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yqe2Cf41_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GSk4so9D_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GqFCp6XC_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n9WvcjhW_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oe0vSwHn_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jYLtuA4F_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bNkcI8qc_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XgpreLLH_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OZqUEmXY_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UGxOhu9m_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pliQlRq6_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3uHq0nJK_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iH8AeHxw_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BnvQJyR2_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rWiuYMQj_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3FUJqv01_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_YzUU237J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L7ezZcnM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_YuQGj9Kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_whd52NTu_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_whd52NTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_YuS6lzzH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YuS6lzzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kWcGtjVr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kWcGtjVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UHOnhPGH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3gm2rVJM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3gm2rVJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GaxfJF12_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_UHOnhPGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_w3CGCuFa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_w3CGCuFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_b0CuZnAJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GaxfJF12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Tq7ri5QV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Tq7ri5QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nDJ3rHFt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_b0CuZnAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zogENK0B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_nDJ3rHFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tNUcYXSe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_SI17Z5cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VO4sxoxh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_PDfqijgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FRLXmH9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_9DCjb5bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j3cRgf8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_SCQx2JxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c3w0PtPM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_mOmQZ2V2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pt7BGcim_sendMessage);
  cMsg_iNh4ci8m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_Pt7BGcim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mOmQZ2V2, 1, m, &cVar_mOmQZ2V2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zHSlAYiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LK0xj7oe_sendMessage(_c, 0, m);
  cMsg_YfKCxwBg_sendMessage(_c, 0, m);
  cMsg_7ghMVfrn_sendMessage(_c, 0, m);
  cMsg_OOmskGmR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_JQY44d9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qzo7lZcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_qAMrcZJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mn691FPN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_K06ytC1F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_882LDN7N_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BwKQ5hjZ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bcchM8mJ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNGaek5p_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vs1z8Kr4_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aOCwsrbq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_882LDN7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Mt7S3TI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_BwKQ5hjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lQMTN3gV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_bcchM8mJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N5LCeOgA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_oNGaek5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yhlKBJHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Vs1z8Kr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eIcGfANU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_aOCwsrbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZJkga9oA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_98ONVNgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TsKBrQlO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_m1aNCc7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Gap0m4KO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_IkHIeXsb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2AXwKpNr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2AXwKpNr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jgaauHfr, 1, m, &cDelay_jgaauHfr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NGNhsMDR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_jgaauHfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jgaauHfr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_98ONVNgn, 0, m, &cIf_98ONVNgn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2AXwKpNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jgaauHfr, 0, m, &cDelay_jgaauHfr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NGNhsMDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jgaauHfr, 0, m, &cDelay_jgaauHfr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GgF9LWmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_31J8zVMZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OmAW4Feo_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PGjAhSku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wg4WwGnS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SU0N7hjc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SU0N7hjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IkHIeXsb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_wg4WwGnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_98ONVNgn, 1, m, &cIf_98ONVNgn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OmAW4Feo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m1aNCc7C, 0, m, &cIf_m1aNCc7C_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_31J8zVMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m1aNCc7C, 1, m, &cIf_m1aNCc7C_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Gap0m4KO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ishI1gPi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TsKBrQlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ishI1gPi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vqdWvSzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yJf1ohTK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tgfpCLph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wouZ5RNd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_PMOCKjkR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dH0s1Pog_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dH0s1Pog_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_O8VMeOxt, 1, m, &cDelay_O8VMeOxt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xUDFJhpe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_O8VMeOxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O8VMeOxt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vqdWvSzr, 0, m, &cIf_vqdWvSzr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dH0s1Pog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_O8VMeOxt, 0, m, &cDelay_O8VMeOxt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xUDFJhpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_O8VMeOxt, 0, m, &cDelay_O8VMeOxt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0STKPWre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JfnLezyo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fDg7LzBp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xfkNZh6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vjppVeRd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wEVFzDud_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vjppVeRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vqdWvSzr, 1, m, &cIf_vqdWvSzr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wEVFzDud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PMOCKjkR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JfnLezyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tgfpCLph, 1, m, &cIf_tgfpCLph_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fDg7LzBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tgfpCLph, 0, m, &cIf_tgfpCLph_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wouZ5RNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OWwE4qbb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yJf1ohTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OWwE4qbb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_WnRmHkIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0Sx47tpb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_LTEyXX22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VNzbOiZ8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_jcNSuczC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mSgYuiBO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mSgYuiBO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ACgWMniS, 1, m, &cDelay_ACgWMniS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3k8Wyeop_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ACgWMniS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ACgWMniS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WnRmHkIL, 0, m, &cIf_WnRmHkIL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mSgYuiBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ACgWMniS, 0, m, &cDelay_ACgWMniS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3k8Wyeop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ACgWMniS, 0, m, &cDelay_ACgWMniS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_myBIzWgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AyMVLj0v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x0ufym6Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_QKmrT3MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OxBNrPy0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xpgf47aU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xpgf47aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jcNSuczC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OxBNrPy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WnRmHkIL, 1, m, &cIf_WnRmHkIL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AyMVLj0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LTEyXX22, 1, m, &cIf_LTEyXX22_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_x0ufym6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LTEyXX22, 0, m, &cIf_LTEyXX22_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VNzbOiZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_doflGaew, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0Sx47tpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_doflGaew, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_o6OzwtsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1rGBNEQT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_vH4uftvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fXXo38d5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_LCPTFSXc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_B8hd2Vp1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_B8hd2Vp1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pTW8eBk1, 1, m, &cDelay_pTW8eBk1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8v4Cjcn6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_pTW8eBk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pTW8eBk1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_o6OzwtsT, 0, m, &cIf_o6OzwtsT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_B8hd2Vp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pTW8eBk1, 0, m, &cDelay_pTW8eBk1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8v4Cjcn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pTW8eBk1, 0, m, &cDelay_pTW8eBk1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pcgKIqAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_be7I2sfw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NmEJDUN5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_osSZEGXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xciVpCUK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gbfulCH8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gbfulCH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LCPTFSXc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_xciVpCUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o6OzwtsT, 1, m, &cIf_o6OzwtsT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_be7I2sfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vH4uftvg, 1, m, &cIf_vH4uftvg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NmEJDUN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vH4uftvg, 0, m, &cIf_vH4uftvg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fXXo38d5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fFF6wSdp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_1rGBNEQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fFF6wSdp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_VMPffmRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LVe946XU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Xms6omyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tvfGcDxC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_gqHowr2S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WxmpPMBh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WxmpPMBh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cAIAAoYB, 1, m, &cDelay_cAIAAoYB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rbkkAv3Y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_cAIAAoYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cAIAAoYB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VMPffmRJ, 0, m, &cIf_VMPffmRJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WxmpPMBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cAIAAoYB, 0, m, &cDelay_cAIAAoYB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rbkkAv3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cAIAAoYB, 0, m, &cDelay_cAIAAoYB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vtr0bpYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tX0J7J3u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ohI4194z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1Xc0mnBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tMrWMCsD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GOXca1te_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GOXca1te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gqHowr2S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_tMrWMCsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMPffmRJ, 1, m, &cIf_VMPffmRJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ohI4194z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xms6omyW, 0, m, &cIf_Xms6omyW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tX0J7J3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xms6omyW, 1, m, &cIf_Xms6omyW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tvfGcDxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_raZvvW9o, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LVe946XU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_raZvvW9o, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_UGyI9idh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LkRnZ5Vj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BSmHXenY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3zhwmPhH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_arC9chvz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m7UJmMs6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m7UJmMs6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zJwCZUcs, 1, m, &cDelay_zJwCZUcs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qmevK7hl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_zJwCZUcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zJwCZUcs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UGyI9idh, 0, m, &cIf_UGyI9idh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_m7UJmMs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zJwCZUcs, 0, m, &cDelay_zJwCZUcs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qmevK7hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zJwCZUcs, 0, m, &cDelay_zJwCZUcs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_obqnJK4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pMB1O4Aj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K55pvSjz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iW3tYKBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3p9G7XZh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iGm8GvRB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iGm8GvRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_arC9chvz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_3p9G7XZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UGyI9idh, 1, m, &cIf_UGyI9idh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pMB1O4Aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BSmHXenY, 1, m, &cIf_BSmHXenY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_K55pvSjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BSmHXenY, 0, m, &cIf_BSmHXenY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3zhwmPhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vQ3qLIBE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LkRnZ5Vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vQ3qLIBE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_GsFe5I8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aEds4p9X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_xFUzHloO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AUKdav6w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_AXboGeOB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QKrFO9aj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QKrFO9aj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aCWJtHkR, 1, m, &cDelay_aCWJtHkR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qYk4PN9I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_aCWJtHkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aCWJtHkR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GsFe5I8x, 0, m, &cIf_GsFe5I8x_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QKrFO9aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aCWJtHkR, 0, m, &cDelay_aCWJtHkR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qYk4PN9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aCWJtHkR, 0, m, &cDelay_aCWJtHkR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3MwQ26Pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NNaWfI42_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UsWL09i1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_I5oRQ0ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sOoeiUkl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tREFqQpM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sOoeiUkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GsFe5I8x, 1, m, &cIf_GsFe5I8x_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tREFqQpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AXboGeOB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_UsWL09i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xFUzHloO, 0, m, &cIf_xFUzHloO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NNaWfI42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xFUzHloO, 1, m, &cIf_xFUzHloO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AUKdav6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G0tln4XA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_aEds4p9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G0tln4XA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_6E3ohwc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UjFDGOrj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_EWWIBmVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eIjZIvbH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_FDLaRdjf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GkGkIG7n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GkGkIG7n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M4W20Wbr, 1, m, &cDelay_M4W20Wbr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JKlPRRwG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_M4W20Wbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M4W20Wbr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6E3ohwc6, 0, m, &cIf_6E3ohwc6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GkGkIG7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4W20Wbr, 0, m, &cDelay_M4W20Wbr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JKlPRRwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4W20Wbr, 0, m, &cDelay_M4W20Wbr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Kk41bn2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUfTotcv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oQN6JznR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fwrr5ywo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3MnheWGm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9mEMNXuC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9mEMNXuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FDLaRdjf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_3MnheWGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6E3ohwc6, 1, m, &cIf_6E3ohwc6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oQN6JznR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EWWIBmVe, 0, m, &cIf_EWWIBmVe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GUfTotcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EWWIBmVe, 1, m, &cIf_EWWIBmVe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eIjZIvbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_58QEIvpx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_UjFDGOrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_58QEIvpx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_5cXcUaGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iImv4UGK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_QrbfOcA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U15cErmW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tXpZYUqR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OUS0N6rl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OUS0N6rl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fEcrxq99, 1, m, &cDelay_fEcrxq99_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xosqAeRB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_fEcrxq99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fEcrxq99, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5cXcUaGr, 0, m, &cIf_5cXcUaGr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OUS0N6rl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fEcrxq99, 0, m, &cDelay_fEcrxq99_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xosqAeRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fEcrxq99, 0, m, &cDelay_fEcrxq99_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_z9r8QJ5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jetCk0rq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3gM1ceXZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KotKlyks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5nE4lADj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A8fa72Ud_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_A8fa72Ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tXpZYUqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_5nE4lADj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5cXcUaGr, 1, m, &cIf_5cXcUaGr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jetCk0rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QrbfOcA4, 1, m, &cIf_QrbfOcA4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3gM1ceXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QrbfOcA4, 0, m, &cIf_QrbfOcA4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_U15cErmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QqgroNRZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iImv4UGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QqgroNRZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_dfdsHqcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lhoKd1IM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_QENMdQxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QyxQdHbr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_MKBdhdv9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OcyxWtio_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OcyxWtio_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VouWCzJs, 1, m, &cDelay_VouWCzJs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PktapTtT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_VouWCzJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VouWCzJs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dfdsHqcK, 0, m, &cIf_dfdsHqcK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OcyxWtio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VouWCzJs, 0, m, &cDelay_VouWCzJs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PktapTtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VouWCzJs, 0, m, &cDelay_VouWCzJs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1BQV1jSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JU4OwQba_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ys4TpAzG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OxdsEOxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o22QAjgC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mfXdsqiH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mfXdsqiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MKBdhdv9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_o22QAjgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dfdsHqcK, 1, m, &cIf_dfdsHqcK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ys4TpAzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QENMdQxW, 0, m, &cIf_QENMdQxW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JU4OwQba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QENMdQxW, 1, m, &cIf_QENMdQxW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QyxQdHbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3sjIzpr4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lhoKd1IM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3sjIzpr4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_cHFHWFBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yVlmrlOX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_s17DN19o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qDmQA3O2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_g6XPDHik_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TO4JGQBR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TO4JGQBR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ts5DrmZA, 1, m, &cDelay_ts5DrmZA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dUEDzzNx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ts5DrmZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ts5DrmZA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cHFHWFBW, 0, m, &cIf_cHFHWFBW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TO4JGQBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ts5DrmZA, 0, m, &cDelay_ts5DrmZA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dUEDzzNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ts5DrmZA, 0, m, &cDelay_ts5DrmZA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zMWtL2Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1KaBbRTs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k1GkhO4p_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xxGoUQtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3LvL1Hr0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_84tACtll_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_84tACtll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_g6XPDHik_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_3LvL1Hr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cHFHWFBW, 1, m, &cIf_cHFHWFBW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1KaBbRTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s17DN19o, 1, m, &cIf_s17DN19o_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_k1GkhO4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s17DN19o, 0, m, &cIf_s17DN19o_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qDmQA3O2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eCNUsoJ0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yVlmrlOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eCNUsoJ0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_MOzDvUHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jdP5BxoL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0qC8A2AX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xxVgnEgM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_h37W38a0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lqiLnuSK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lqiLnuSK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pmicEo1c, 1, m, &cDelay_pmicEo1c_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_el9HRaqu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_pmicEo1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pmicEo1c, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MOzDvUHu, 0, m, &cIf_MOzDvUHu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lqiLnuSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pmicEo1c, 0, m, &cDelay_pmicEo1c_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_el9HRaqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pmicEo1c, 0, m, &cDelay_pmicEo1c_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XRVA2bos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EzD7SUjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LSJXkPxx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cFU3dY7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AZG3BTXa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YzJcMdDp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YzJcMdDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_h37W38a0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AZG3BTXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MOzDvUHu, 1, m, &cIf_MOzDvUHu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LSJXkPxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0qC8A2AX, 0, m, &cIf_0qC8A2AX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EzD7SUjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0qC8A2AX, 1, m, &cIf_0qC8A2AX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xxVgnEgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wnUBfvYG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jdP5BxoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wnUBfvYG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7Mt7S3TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_cIVltwMv_sendMessage(_c, 0, m);
  cMsg_7O5XbcSF_sendMessage(_c, 0, m);
  cMsg_EWlFHwS7_sendMessage(_c, 0, m);
  cMsg_viI2KyHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lQMTN3gV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_cIVltwMv_sendMessage(_c, 0, m);
  cMsg_99Ygqoot_sendMessage(_c, 0, m);
  cMsg_MuXiN1tI_sendMessage(_c, 0, m);
  cMsg_LLLqrVRU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_N5LCeOgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_HLlX6w8B_sendMessage(_c, 0, m);
  cMsg_99Ygqoot_sendMessage(_c, 0, m);
  cMsg_viI2KyHF_sendMessage(_c, 0, m);
  cMsg_MR7DJWNo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_yhlKBJHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_HLlX6w8B_sendMessage(_c, 0, m);
  cMsg_EpRCKgez_sendMessage(_c, 0, m);
  cMsg_EWlFHwS7_sendMessage(_c, 0, m);
  cMsg_KRliVQJz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eIcGfANU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_pRLTF7xQ_sendMessage(_c, 0, m);
  cMsg_LLLqrVRU_sendMessage(_c, 0, m);
  cMsg_E9QF3ElJ_sendMessage(_c, 0, m);
  cMsg_EWlFHwS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZJkga9oA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_pRLTF7xQ_sendMessage(_c, 0, m);
  cMsg_KRliVQJz_sendMessage(_c, 0, m);
  cMsg_99Ygqoot_sendMessage(_c, 0, m);
  cMsg_T34QIoTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_j5bt7oc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PGjAhSku_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GgF9LWmS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nU9b7QBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PGjAhSku_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GgF9LWmS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HcmFD1Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xfkNZh6e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0STKPWre_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EPXclH4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xfkNZh6e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0STKPWre_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zjseA60R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QKmrT3MN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_myBIzWgn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DQTnvRrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QKmrT3MN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_myBIzWgn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cIVltwMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_j5bt7oc2_sendMessage(_c, 0, m);
  cMsg_EPXclH4d_sendMessage(_c, 0, m);
  cMsg_DQTnvRrg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HLlX6w8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_nU9b7QBX_sendMessage(_c, 0, m);
  cMsg_HcmFD1Lv_sendMessage(_c, 0, m);
  cMsg_DQTnvRrg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_pRLTF7xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_nU9b7QBX_sendMessage(_c, 0, m);
  cMsg_EPXclH4d_sendMessage(_c, 0, m);
  cMsg_zjseA60R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Mbxywx9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_osSZEGXl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pcgKIqAN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WQVMRqdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_osSZEGXl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pcgKIqAN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_F54ARCej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1Xc0mnBE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vtr0bpYC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uDbtQHFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1Xc0mnBE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vtr0bpYC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_H5wY99Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iW3tYKBW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_obqnJK4i_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IybPevhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iW3tYKBW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_obqnJK4i_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_99Ygqoot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WQVMRqdl_sendMessage(_c, 0, m);
  cMsg_uDbtQHFk_sendMessage(_c, 0, m);
  cMsg_IybPevhg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7O5XbcSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WQVMRqdl_sendMessage(_c, 0, m);
  cMsg_F54ARCej_sendMessage(_c, 0, m);
  cMsg_H5wY99Ij_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_EpRCKgez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Mbxywx9b_sendMessage(_c, 0, m);
  cMsg_uDbtQHFk_sendMessage(_c, 0, m);
  cMsg_H5wY99Ij_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rqNJCfAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OxdsEOxe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1BQV1jSn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YjYLF0hA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OxdsEOxe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1BQV1jSn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3ed3YdPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xxGoUQtH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zMWtL2Dj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OE8L8hoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xxGoUQtH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zMWtL2Dj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kLhTDw0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cFU3dY7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRVA2bos_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_V6ANVUGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cFU3dY7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XRVA2bos_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KRliVQJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_rqNJCfAb_sendMessage(_c, 0, m);
  cMsg_OE8L8hoy_sendMessage(_c, 0, m);
  cMsg_V6ANVUGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_LLLqrVRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_YjYLF0hA_sendMessage(_c, 0, m);
  cMsg_3ed3YdPy_sendMessage(_c, 0, m);
  cMsg_V6ANVUGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_viI2KyHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_YjYLF0hA_sendMessage(_c, 0, m);
  cMsg_OE8L8hoy_sendMessage(_c, 0, m);
  cMsg_kLhTDw0G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CfqKM7Nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I5oRQ0ih_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3MwQ26Pu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9XtmXbqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I5oRQ0ih_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3MwQ26Pu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XYlAhQNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fwrr5ywo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kk41bn2S_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EYFa0y8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fwrr5ywo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kk41bn2S_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_InVUXec3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KotKlyks_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z9r8QJ5I_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SvPL7urG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KotKlyks_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z9r8QJ5I_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EWlFHwS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_9XtmXbqe_sendMessage(_c, 0, m);
  cMsg_EYFa0y8q_sendMessage(_c, 0, m);
  cMsg_SvPL7urG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MuXiN1tI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_9XtmXbqe_sendMessage(_c, 0, m);
  cMsg_XYlAhQNI_sendMessage(_c, 0, m);
  cMsg_InVUXec3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_T34QIoTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_CfqKM7Nx_sendMessage(_c, 0, m);
  cMsg_XYlAhQNI_sendMessage(_c, 0, m);
  cMsg_SvPL7urG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_E9QF3ElJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Mbxywx9b_sendMessage(_c, 0, m);
  cMsg_F54ARCej_sendMessage(_c, 0, m);
  cMsg_IybPevhg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MR7DJWNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_CfqKM7Nx_sendMessage(_c, 0, m);
  cMsg_EYFa0y8q_sendMessage(_c, 0, m);
  cMsg_InVUXec3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_n9cPfurm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ymH8CcXP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_GqOzB8N9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qdriSA6I, 0, m, &cSlice_qdriSA6I_sendMessage);
      break;
    }
    default: {
      cSwitchcase_j7MS6UMi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_qdriSA6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_44fSatEe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_44fSatEe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_Jthgbuyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_44fSatEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_44fSatEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oe0vSwHn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_PYtUBXdy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9uM92vrd, 0, m, &cSlice_9uM92vrd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OxduJUKo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_9uM92vrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IiIGDw6D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IiIGDw6D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_w2zC2QCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IiIGDw6D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_IiIGDw6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OZqUEmXY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_OxduJUKo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wilti4gd, 0, m, &cSlice_wilti4gd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GqOzB8N9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_wilti4gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V4hM8jgf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V4hM8jgf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_6lRo8FbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V4hM8jgf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_V4hM8jgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n9WvcjhW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_j7MS6UMi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ob8WiLKT, 0, m, &cSlice_ob8WiLKT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JPpc59U0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_ob8WiLKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AhOHJe2E_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AhOHJe2E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_OtZp4FYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AhOHJe2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_AhOHJe2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XgpreLLH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_JPpc59U0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zXqeZURy, 0, m, &cSlice_zXqeZURy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2x8OOra7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_zXqeZURy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XFmnw0hC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XFmnw0hC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_nPDINmSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XFmnw0hC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_XFmnw0hC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bNkcI8qc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_to7ZztHQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SjcJ1zDo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SjcJ1zDo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5aBf3rtt, 1, m, &cDelay_5aBf3rtt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qrN0Q2Q2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5aBf3rtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5aBf3rtt, m);
  cMsg_KHJlJTpK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_SjcJ1zDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5aBf3rtt, 0, m, &cDelay_5aBf3rtt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qrN0Q2Q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5aBf3rtt, 0, m, &cDelay_5aBf3rtt_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_TOnL57hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gtP5BNq2, HV_BINOP_SUBTRACT, 0, m, &cBinop_gtP5BNq2_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_o0D5JYLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KyFYktBe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gaygh8tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KyFYktBe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_9gr0j1h1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TOnL57hy, 0, m, &cVar_TOnL57hy_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_vLyDUOqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TCuggkit_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uzsQcQNJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ftp6y48_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gtP5BNq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7hqJ0Hcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7hqJ0Hcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XSiC7Gwg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XSiC7Gwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8ar8jkJu_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_u38uwhfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jxl5Fki6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oDvVw0FD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oDvVw0FD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OsWEkMvT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Jxl5Fki6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o0D5JYLa, 1, m, &cIf_o0D5JYLa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hwzahJTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gaygh8tR, 1, m, &cIf_gaygh8tR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OsWEkMvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_o0D5JYLa, 0, m, &cIf_o0D5JYLa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8ar8jkJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gaygh8tR, 0, m, &cIf_gaygh8tR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TCuggkit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_uzsQcQNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gtP5BNq2, HV_BINOP_SUBTRACT, 1, m, &cBinop_gtP5BNq2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1ftp6y48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TOnL57hy, 0, m, &cVar_TOnL57hy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KyFYktBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L8yYLnq8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_2x8OOra7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_slINcGNI, 0, m, &cSlice_slINcGNI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_slINcGNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KEq7lkDz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KEq7lkDz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_iToTt5aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KEq7lkDz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_KEq7lkDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jYLtuA4F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Qzo7lZcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FaRx2ZOb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_mn691FPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kqBuZREP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_fDgHgY3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qAMrcZJH, 0, m, &cVar_qAMrcZJH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ymH8CcXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iknEXkul, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_GhPC2OtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WwnHA2Kh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_vLDfgbfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_to7ZztHQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KHJlJTpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T2oYDfrU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WwnHA2Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T2oYDfrU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_VKwAyaIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_FhJ0Qozg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FhJ0Qozg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QPTl9Hit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QPTl9Hit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GQmLZRGZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_QkxIgBAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYMhIxmS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_BjvvMxw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6sqec6R8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_NQIH59JX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VztWVOio_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBUuR6V0_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n9WCUidi_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ntiKuF1h_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AIqAB6mM_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hW4Sau0n_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_VztWVOio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YQo18tUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ZBUuR6V0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u83kU1Ce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_n9WCUidi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t9a2MflL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ntiKuF1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYeusPEF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_AIqAB6mM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FF9PYWKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_hW4Sau0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BXUmRvTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_ynepjaVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QwfKYnSJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_OfCnckxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b2aB4zfy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_OuNKKiQf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9ww90vCv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9ww90vCv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OxI1TI52, 1, m, &cDelay_OxI1TI52_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oLNwIOtQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_OxI1TI52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OxI1TI52, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ynepjaVo, 0, m, &cIf_ynepjaVo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9ww90vCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OxI1TI52, 0, m, &cDelay_OxI1TI52_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oLNwIOtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OxI1TI52, 0, m, &cDelay_OxI1TI52_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_A1VHgi2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5JY5smOe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WoF75CJm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EPRsItcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1sCQYddA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HN7lyorD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1sCQYddA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ynepjaVo, 1, m, &cIf_ynepjaVo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HN7lyorD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OuNKKiQf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_WoF75CJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OfCnckxn, 0, m, &cIf_OfCnckxn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5JY5smOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OfCnckxn, 1, m, &cIf_OfCnckxn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_b2aB4zfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DwfYmObS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QwfKYnSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DwfYmObS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_L4wKfEnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9L6xgLK7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_oMT6Qy0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Jy29Zv3g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_8qkPkpSm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BKmrwCEl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BKmrwCEl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Qsbgjiys, 1, m, &cDelay_Qsbgjiys_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1wI0xJRV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Qsbgjiys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qsbgjiys, m);
  cIf_onMessage(_c, &Context(_c)->cIf_L4wKfEnP, 0, m, &cIf_L4wKfEnP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BKmrwCEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qsbgjiys, 0, m, &cDelay_Qsbgjiys_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1wI0xJRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qsbgjiys, 0, m, &cDelay_Qsbgjiys_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Fhm5HmDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XUkmV9ve_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ntat2xja_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_B9liiY57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m96cyYk4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7QLERxns_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7QLERxns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8qkPkpSm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_m96cyYk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L4wKfEnP, 1, m, &cIf_L4wKfEnP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ntat2xja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oMT6Qy0n, 0, m, &cIf_oMT6Qy0n_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XUkmV9ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oMT6Qy0n, 1, m, &cIf_oMT6Qy0n_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Jy29Zv3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2jlbMQpQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9L6xgLK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2jlbMQpQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Ws1XUg5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gfWntK8g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_CFxktKvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9elH8rwq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_rk6FFprX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_V8DeXW3E_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_V8DeXW3E_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_81NVn0M2, 1, m, &cDelay_81NVn0M2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xPi22G6Y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_81NVn0M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_81NVn0M2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ws1XUg5E, 0, m, &cIf_Ws1XUg5E_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_V8DeXW3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_81NVn0M2, 0, m, &cDelay_81NVn0M2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xPi22G6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_81NVn0M2, 0, m, &cDelay_81NVn0M2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kQkflueG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3uLYTKCq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rdHkoP00_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_52QBWTVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DWZrmV4w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eo0KmaMI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Eo0KmaMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rk6FFprX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_DWZrmV4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ws1XUg5E, 1, m, &cIf_Ws1XUg5E_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rdHkoP00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CFxktKvY, 0, m, &cIf_CFxktKvY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3uLYTKCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CFxktKvY, 1, m, &cIf_CFxktKvY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9elH8rwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v9wfl2CI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gfWntK8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v9wfl2CI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_31TZB8qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AeszVYNx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_FFp4tXSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qk2YzuYj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7aCIYhYp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wQI5SBXu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wQI5SBXu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4mnQ4IAd, 1, m, &cDelay_4mnQ4IAd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XMy0qshK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4mnQ4IAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4mnQ4IAd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_31TZB8qr, 0, m, &cIf_31TZB8qr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wQI5SBXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4mnQ4IAd, 0, m, &cDelay_4mnQ4IAd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XMy0qshK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4mnQ4IAd, 0, m, &cDelay_4mnQ4IAd_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YdXcm8rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dUl5elbz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dTeXj6kH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VY5Prad9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UkUribkv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cwqXcaZi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cwqXcaZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7aCIYhYp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_UkUribkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_31TZB8qr, 1, m, &cIf_31TZB8qr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dUl5elbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FFp4tXSd, 1, m, &cIf_FFp4tXSd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dTeXj6kH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FFp4tXSd, 0, m, &cIf_FFp4tXSd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qk2YzuYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h606NhuY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AeszVYNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h606NhuY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_D8Ll39oQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oFXPhejo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_vbn1Nvr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YaidrOlW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_2CmoJrCm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GmgMX0Kp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GmgMX0Kp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zOlBxChH, 1, m, &cDelay_zOlBxChH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_avgPL1fP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_zOlBxChH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zOlBxChH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_D8Ll39oQ, 0, m, &cIf_D8Ll39oQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GmgMX0Kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zOlBxChH, 0, m, &cDelay_zOlBxChH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_avgPL1fP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zOlBxChH, 0, m, &cDelay_zOlBxChH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_shkMXloz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FNAzlPJr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FLZmSveJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_C986f4pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MMhiIXsQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DBK2Gl4A_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DBK2Gl4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2CmoJrCm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_MMhiIXsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D8Ll39oQ, 1, m, &cIf_D8Ll39oQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FNAzlPJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbn1Nvr7, 1, m, &cIf_vbn1Nvr7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FLZmSveJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbn1Nvr7, 0, m, &cIf_vbn1Nvr7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YaidrOlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3jDLoquP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_oFXPhejo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3jDLoquP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_VraYkebg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4mfUmv7G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_AwkblwH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6fXPsCYG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_B1O3YcWA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oofJYv03_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oofJYv03_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7GPcIxp2, 1, m, &cDelay_7GPcIxp2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_procALAv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7GPcIxp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7GPcIxp2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VraYkebg, 0, m, &cIf_VraYkebg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oofJYv03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7GPcIxp2, 0, m, &cDelay_7GPcIxp2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_procALAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7GPcIxp2, 0, m, &cDelay_7GPcIxp2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_apXYYKzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UlUIy7Ia_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s723vQmW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_v025mXUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KMIBgn4h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SIYJXzQO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SIYJXzQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_B1O3YcWA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_KMIBgn4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VraYkebg, 1, m, &cIf_VraYkebg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UlUIy7Ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AwkblwH3, 1, m, &cIf_AwkblwH3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_s723vQmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AwkblwH3, 0, m, &cIf_AwkblwH3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6fXPsCYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kOCgqA2u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4mfUmv7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kOCgqA2u, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Bw51xJJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Msgc8qaA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_zzUmuSuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q0wL4ITf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_q6GZI7Rz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mcuIxj4W_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mcuIxj4W_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_17qfO8iE, 1, m, &cDelay_17qfO8iE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LyDX0S21_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_17qfO8iE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_17qfO8iE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Bw51xJJw, 0, m, &cIf_Bw51xJJw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mcuIxj4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_17qfO8iE, 0, m, &cDelay_17qfO8iE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LyDX0S21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_17qfO8iE, 0, m, &cDelay_17qfO8iE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_q9d9pTTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z98OdDvZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PREA8BL6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AvTAMSAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PefsoUG7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SmlwWnD4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SmlwWnD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_q6GZI7Rz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_PefsoUG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bw51xJJw, 1, m, &cIf_Bw51xJJw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Z98OdDvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zzUmuSuc, 1, m, &cIf_zzUmuSuc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PREA8BL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zzUmuSuc, 0, m, &cIf_zzUmuSuc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Q0wL4ITf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NtyfU5bY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Msgc8qaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NtyfU5bY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_rXvSAh4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WORaUgtm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_vJEtd2sU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SwLrJS8v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_i8UGMHF5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_baRrkqkT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_baRrkqkT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_n1azfGmq, 1, m, &cDelay_n1azfGmq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FXXItN5N_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_n1azfGmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n1azfGmq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rXvSAh4F, 0, m, &cIf_rXvSAh4F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_baRrkqkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_n1azfGmq, 0, m, &cDelay_n1azfGmq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FXXItN5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n1azfGmq, 0, m, &cDelay_n1azfGmq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eO7RyBAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qGx943fX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0AeLLWfJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5Exxq16A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YplD3GRm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LhJY8yGb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LhJY8yGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_i8UGMHF5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YplD3GRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rXvSAh4F, 1, m, &cIf_rXvSAh4F_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0AeLLWfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vJEtd2sU, 0, m, &cIf_vJEtd2sU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qGx943fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vJEtd2sU, 1, m, &cIf_vJEtd2sU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SwLrJS8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CNRF5SMp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WORaUgtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CNRF5SMp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_10hXCoW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yknwF28C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_aQPw6L9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XKtppnk4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3zkxI4i4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dLKqtkr4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dLKqtkr4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MHuvYPB3, 1, m, &cDelay_MHuvYPB3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q4BceeT6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_MHuvYPB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MHuvYPB3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_10hXCoW8, 0, m, &cIf_10hXCoW8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dLKqtkr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHuvYPB3, 0, m, &cDelay_MHuvYPB3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Q4BceeT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHuvYPB3, 0, m, &cDelay_MHuvYPB3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6KS8j4TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UNC5lWIM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4pcNaPit_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0nUCriYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4PeSnUcg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y6on1J1M_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_y6on1J1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3zkxI4i4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_4PeSnUcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_10hXCoW8, 1, m, &cIf_10hXCoW8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4pcNaPit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aQPw6L9E, 0, m, &cIf_aQPw6L9E_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UNC5lWIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aQPw6L9E, 1, m, &cIf_aQPw6L9E_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XKtppnk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1Bj9nx5T, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yknwF28C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1Bj9nx5T, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ryPPdVNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iKk3r2B8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_XLbHdmwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pb4UFj4v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5eoxYUA4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1TFFuYl8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1TFFuYl8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RDHuCMLa, 1, m, &cDelay_RDHuCMLa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h03qHrXi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RDHuCMLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RDHuCMLa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ryPPdVNv, 0, m, &cIf_ryPPdVNv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1TFFuYl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RDHuCMLa, 0, m, &cDelay_RDHuCMLa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_h03qHrXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RDHuCMLa, 0, m, &cDelay_RDHuCMLa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KXI7luis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FWLrBIjw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VW7KWjm9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dMVXGkd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CiVL0wnA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ECuXHYTy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CiVL0wnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ryPPdVNv, 1, m, &cIf_ryPPdVNv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ECuXHYTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5eoxYUA4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_FWLrBIjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XLbHdmwV, 1, m, &cIf_XLbHdmwV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VW7KWjm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XLbHdmwV, 0, m, &cIf_XLbHdmwV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pb4UFj4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iGWpmTX6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iKk3r2B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iGWpmTX6, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_bii7eccZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_auAIrPEO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tAuePGnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8kD9dBdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bVKHk7Cb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Rtz2NL05_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Rtz2NL05_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B5ZsRXho, 1, m, &cDelay_B5ZsRXho_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z3jKaUYq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_B5ZsRXho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B5ZsRXho, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bii7eccZ, 0, m, &cIf_bii7eccZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Rtz2NL05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B5ZsRXho, 0, m, &cDelay_B5ZsRXho_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_z3jKaUYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B5ZsRXho, 0, m, &cDelay_B5ZsRXho_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_U57JK18M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aU6ginMZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YqS5GscR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KFW9MULl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ve3luNKL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eLze4t8X_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eLze4t8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bVKHk7Cb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ve3luNKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bii7eccZ, 1, m, &cIf_bii7eccZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YqS5GscR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tAuePGnv, 0, m, &cIf_tAuePGnv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aU6ginMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tAuePGnv, 1, m, &cIf_tAuePGnv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8kD9dBdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1EuQrMyW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_auAIrPEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1EuQrMyW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_WDwUW8O4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U5jP7tqZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_dc91boyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BivMa4Dp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_koiDQZY3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x15nixc8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x15nixc8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ngUxY8gn, 1, m, &cDelay_ngUxY8gn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kblI8Onj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ngUxY8gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ngUxY8gn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WDwUW8O4, 0, m, &cIf_WDwUW8O4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x15nixc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ngUxY8gn, 0, m, &cDelay_ngUxY8gn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kblI8Onj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ngUxY8gn, 0, m, &cDelay_ngUxY8gn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oUqiTebN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RYmQ6Msb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bZziNaBe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_as6Ynfps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CsxTLSxP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7sV1i4DF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CsxTLSxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WDwUW8O4, 1, m, &cIf_WDwUW8O4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7sV1i4DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_koiDQZY3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_RYmQ6Msb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dc91boyt, 1, m, &cIf_dc91boyt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bZziNaBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dc91boyt, 0, m, &cIf_dc91boyt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BivMa4Dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nVZTVLz7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_U5jP7tqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nVZTVLz7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_YQo18tUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_2yYHGCLJ_sendMessage(_c, 0, m);
  cMsg_Z38HzE8Z_sendMessage(_c, 0, m);
  cMsg_gvo7xFRM_sendMessage(_c, 0, m);
  cMsg_8fhChKhm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_u83kU1Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_2yYHGCLJ_sendMessage(_c, 0, m);
  cMsg_YCefY2k5_sendMessage(_c, 0, m);
  cMsg_2JD9afWZ_sendMessage(_c, 0, m);
  cMsg_gmimQIL2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_t9a2MflL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_m78zhSE6_sendMessage(_c, 0, m);
  cMsg_YCefY2k5_sendMessage(_c, 0, m);
  cMsg_8fhChKhm_sendMessage(_c, 0, m);
  cMsg_CktyFJf3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PYeusPEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_m78zhSE6_sendMessage(_c, 0, m);
  cMsg_oZcZt9JV_sendMessage(_c, 0, m);
  cMsg_gvo7xFRM_sendMessage(_c, 0, m);
  cMsg_NMXw0IEn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_FF9PYWKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_LVXqByex_sendMessage(_c, 0, m);
  cMsg_gmimQIL2_sendMessage(_c, 0, m);
  cMsg_MYTTBOqM_sendMessage(_c, 0, m);
  cMsg_gvo7xFRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BXUmRvTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_LVXqByex_sendMessage(_c, 0, m);
  cMsg_NMXw0IEn_sendMessage(_c, 0, m);
  cMsg_YCefY2k5_sendMessage(_c, 0, m);
  cMsg_jHhJzaIi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0k7Zng5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EPRsItcT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_A1VHgi2U_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VU2WPSCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EPRsItcT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_A1VHgi2U_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_41te33XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B9liiY57_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Fhm5HmDR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eVUY3NZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B9liiY57_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Fhm5HmDR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HmfjdDwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_52QBWTVT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kQkflueG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DxXPNIm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_52QBWTVT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kQkflueG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2yYHGCLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_0k7Zng5e_sendMessage(_c, 0, m);
  cMsg_eVUY3NZj_sendMessage(_c, 0, m);
  cMsg_DxXPNIm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_m78zhSE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_VU2WPSCb_sendMessage(_c, 0, m);
  cMsg_41te33XZ_sendMessage(_c, 0, m);
  cMsg_DxXPNIm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_LVXqByex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_VU2WPSCb_sendMessage(_c, 0, m);
  cMsg_eVUY3NZj_sendMessage(_c, 0, m);
  cMsg_HmfjdDwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7CQD4D3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VY5Prad9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YdXcm8rq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6Kt5O8ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VY5Prad9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YdXcm8rq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4VBJeJjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C986f4pc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_shkMXloz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mTGR9PLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C986f4pc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_shkMXloz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QOeICj4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v025mXUZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_apXYYKzm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SrWgeEEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_v025mXUZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_apXYYKzm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YCefY2k5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_6Kt5O8ld_sendMessage(_c, 0, m);
  cMsg_mTGR9PLj_sendMessage(_c, 0, m);
  cMsg_SrWgeEEk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Z38HzE8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_6Kt5O8ld_sendMessage(_c, 0, m);
  cMsg_4VBJeJjo_sendMessage(_c, 0, m);
  cMsg_QOeICj4u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oZcZt9JV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_7CQD4D3h_sendMessage(_c, 0, m);
  cMsg_mTGR9PLj_sendMessage(_c, 0, m);
  cMsg_QOeICj4u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xBDccXc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dMVXGkd4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KXI7luis_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NPwH72hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dMVXGkd4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KXI7luis_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_w4FU6Ska_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KFW9MULl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_U57JK18M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2pPv2t84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KFW9MULl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_U57JK18M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ws5ddfRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_as6Ynfps_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oUqiTebN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3Ss3zctu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_as6Ynfps_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oUqiTebN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NMXw0IEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_xBDccXc2_sendMessage(_c, 0, m);
  cMsg_2pPv2t84_sendMessage(_c, 0, m);
  cMsg_3Ss3zctu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gmimQIL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_NPwH72hW_sendMessage(_c, 0, m);
  cMsg_w4FU6Ska_sendMessage(_c, 0, m);
  cMsg_3Ss3zctu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8fhChKhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_NPwH72hW_sendMessage(_c, 0, m);
  cMsg_2pPv2t84_sendMessage(_c, 0, m);
  cMsg_ws5ddfRv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TuC12kpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AvTAMSAP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_q9d9pTTp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AwO2pZPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AvTAMSAP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_q9d9pTTp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5Jhmflrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5Exxq16A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eO7RyBAr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Lc9SoAjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5Exxq16A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eO7RyBAr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BOXsuQr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0nUCriYF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6KS8j4TN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fbzBo2aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0nUCriYF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6KS8j4TN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gvo7xFRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_AwO2pZPV_sendMessage(_c, 0, m);
  cMsg_Lc9SoAjz_sendMessage(_c, 0, m);
  cMsg_fbzBo2aU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_2JD9afWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_AwO2pZPV_sendMessage(_c, 0, m);
  cMsg_5Jhmflrg_sendMessage(_c, 0, m);
  cMsg_BOXsuQr1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jHhJzaIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_TuC12kpY_sendMessage(_c, 0, m);
  cMsg_5Jhmflrg_sendMessage(_c, 0, m);
  cMsg_fbzBo2aU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MYTTBOqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_7CQD4D3h_sendMessage(_c, 0, m);
  cMsg_4VBJeJjo_sendMessage(_c, 0, m);
  cMsg_SrWgeEEk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CktyFJf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_TuC12kpY_sendMessage(_c, 0, m);
  cMsg_Lc9SoAjz_sendMessage(_c, 0, m);
  cMsg_BOXsuQr1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_vsrh8MlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0IvROCEF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_KcJkE1ZW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0cONtAfW, 0, m, &cSlice_0cONtAfW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LIsbeuUr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_0cONtAfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jhvXmPQT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jhvXmPQT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_9MQeIf7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jhvXmPQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_jhvXmPQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pliQlRq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_0IlBykEs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_He4a7qya, 0, m, &cSlice_He4a7qya_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mb3N3jXP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_He4a7qya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hb4sXWyZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hb4sXWyZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_s3hHEIiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hb4sXWyZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_hb4sXWyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rWiuYMQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_mb3N3jXP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7eaPUv04, 0, m, &cSlice_7eaPUv04_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KcJkE1ZW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_7eaPUv04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IDeDQISI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IDeDQISI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_DNQMiX1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IDeDQISI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_IDeDQISI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UGxOhu9m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_LIsbeuUr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1OuaXGwM, 0, m, &cSlice_1OuaXGwM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Fw4Scv9R_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_1OuaXGwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_evm63l4j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_evm63l4j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_9dTgqEwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_evm63l4j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_evm63l4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BnvQJyR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Fw4Scv9R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DRYq3RA5, 0, m, &cSlice_DRYq3RA5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_p9XYXcDS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_DRYq3RA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iLOvQCGH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iLOvQCGH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_8zqBy3Cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iLOvQCGH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_iLOvQCGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iH8AeHxw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_hK9wRA5O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4F9m8kKN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4F9m8kKN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nltQ07IJ, 1, m, &cDelay_nltQ07IJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SFbrZ4Xu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_nltQ07IJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nltQ07IJ, m);
  cMsg_TRPJVmDb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4F9m8kKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nltQ07IJ, 0, m, &cDelay_nltQ07IJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SFbrZ4Xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nltQ07IJ, 0, m, &cDelay_nltQ07IJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_HnlIQOLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NsTLVJXj, HV_BINOP_SUBTRACT, 0, m, &cBinop_NsTLVJXj_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_A7W0Rkxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bfKyu2jl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nQSLrJ9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bfKyu2jl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_zWCxrp3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HnlIQOLW, 0, m, &cVar_HnlIQOLW_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_7LOlVo3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HCl43DYB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wLC95sg1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NCOQYdiB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NsTLVJXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZVevRRvO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZVevRRvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_STzsb2BX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_STzsb2BX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7shYsaoB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gUFVhQtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FJ5Y9kmF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lckv2JDl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FJ5Y9kmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A7W0Rkxw, 1, m, &cIf_A7W0Rkxw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Lckv2JDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CQ6H7la4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_WkAQ7TVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nQSLrJ9a, 1, m, &cIf_nQSLrJ9a_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CQ6H7la4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_A7W0Rkxw, 0, m, &cIf_A7W0Rkxw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7shYsaoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nQSLrJ9a, 0, m, &cIf_nQSLrJ9a_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wLC95sg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NsTLVJXj, HV_BINOP_SUBTRACT, 1, m, &cBinop_NsTLVJXj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HCl43DYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_NCOQYdiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HnlIQOLW, 0, m, &cVar_HnlIQOLW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bfKyu2jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dwleamw2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_p9XYXcDS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jYaEaF3K, 0, m, &cSlice_jYaEaF3K_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_jYaEaF3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_h933D0Eq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_h933D0Eq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_a5NKn76p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h933D0Eq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_h933D0Eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3uHq0nJK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PYMhIxmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HqUm03ih, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_6sqec6R8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WpbUbgIi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_lwKtyTzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BjvvMxw8, 0, m, &cVar_BjvvMxw8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0IvROCEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3AHwNz2U, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_MzRcqcvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hK9wRA5O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_bHEIp5Lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eFoYHzBc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TRPJVmDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xDXGHvZ4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eFoYHzBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xDXGHvZ4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_P2UT2fV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_5XEyRT2W_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5XEyRT2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GktmkA81_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_GktmkA81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FcYiKPZ8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_AX4kDfG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sBqJRjDN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zogENK0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uhNS3O2d, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_tNUcYXSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q9NEY9QL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_VO4sxoxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GqFCp6XC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_L7ezZcnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PYtUBXdy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0IlBykEs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_j3cRgf8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PYtUBXdy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0IlBykEs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_pgVjYuRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SI17Z5cu, 0, m, &cVar_SI17Z5cu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FRLXmH9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PYtUBXdy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0IlBykEs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_c3w0PtPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PYtUBXdy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0IlBykEs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iNh4ci8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PYtUBXdy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0IlBykEs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LK0xj7oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9DCjb5bc, 0, m, &cVar_9DCjb5bc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YfKCxwBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PDfqijgf, 0, m, &cVar_PDfqijgf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SCQx2JxB, 0, m, &cVar_SCQx2JxB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7ghMVfrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pgVjYuRp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RVTTmsB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_mOmQZ2V2, 0, m, &cVar_mOmQZ2V2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sBqJRjDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PYtUBXdy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0IlBykEs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_OOmskGmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_AX4kDfG9, 0, m, &cVar_AX4kDfG9_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_GqFCp6XC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YuQGj9Kx_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_GSk4so9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YzUU237J, 0, m, &cVar_YzUU237J_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_jffgovOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pgVjYuRp_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_x8xOfVAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9DCjb5bc, 0, m, &cVar_9DCjb5bc_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3FUJqv01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jthgbuyr, 0, m, &cVar_Jthgbuyr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w2zC2QCG, 0, m, &cVar_w2zC2QCG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6lRo8FbN, 0, m, &cVar_6lRo8FbN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OtZp4FYc, 0, m, &cVar_OtZp4FYc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nPDINmSP, 0, m, &cVar_nPDINmSP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iToTt5aQ, 0, m, &cVar_iToTt5aQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9MQeIf7d, 0, m, &cVar_9MQeIf7d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s3hHEIiP, 0, m, &cVar_s3hHEIiP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DNQMiX1S, 0, m, &cVar_DNQMiX1S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9dTgqEwF, 0, m, &cVar_9dTgqEwF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8zqBy3Cn, 0, m, &cVar_8zqBy3Cn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a5NKn76p, 0, m, &cVar_a5NKn76p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zHSlAYiy_sendMessage);
  cMsg_RVTTmsB8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_bNTWSz3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mOmQZ2V2, 0, m, &cVar_mOmQZ2V2_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_quAUAL6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PDfqijgf, 0, m, &cVar_PDfqijgf_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Yqe2Cf41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SCQx2JxB, 0, m, &cVar_SCQx2JxB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_oe0vSwHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JQY44d9x, 0, m, &cVar_JQY44d9x_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_XgpreLLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n9cPfurm, 0, m, &cVar_n9cPfurm_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_n9WvcjhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_fDgHgY3d_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_OZqUEmXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_K06ytC1F_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GhPC2OtH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vLDfgbfB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_bNkcI8qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u38uwhfq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hwzahJTs_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_jYLtuA4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VKwAyaIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_pliQlRq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QkxIgBAV, 0, m, &cVar_QkxIgBAV_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_BnvQJyR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vsrh8MlR, 0, m, &cVar_vsrh8MlR_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_UGxOhu9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_lwKtyTzK_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_rWiuYMQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NQIH59JX_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bHEIp5Lx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MzRcqcvq_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_iH8AeHxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gUFVhQtY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WkAQ7TVm_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3uHq0nJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2UT2fV9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_sWNf9Xup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AX4kDfG9, 0, m, &cVar_AX4kDfG9_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_R2041KNk, VIf(I0));
    __hv_varread_f(&sVarf_UTvU3obp, VOf(Bf0));
    __hv_varread_f(&sVarf_xPgze1ER, VOf(Bf1));
    __hv_varread_f(&sVarf_wCc4Sm45, VOf(Bf2));
    __hv_varread_f(&sVarf_aOS4qwsz, VOf(Bf3));
    __hv_varread_f(&sVarf_rGxdkI0s, VOf(Bf4));
    __hv_varread_f(&sVarf_i8MnBXhy, VOf(Bf5));
    __hv_varread_f(&sVarf_eq4Qf41g, VOf(Bf6));
    __hv_varwrite_f(&sVarf_CzNkM2Uv, VIf(I0));
    __hv_varread_f(&sVarf_pMVu6uR5, VOf(Bf7));
    __hv_line_f(&sLine_3sjIzpr4, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lY5BOI3L, VOf(Bf9));
    __hv_line_f(&sLine_eCNUsoJ0, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_rpY57DEc, VOf(Bf8));
    __hv_line_f(&sLine_wnUBfvYG, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_aOS4qwsz, VIf(Bf11));
    __hv_varread_f(&sVarf_CzNkM2Uv, VOf(Bf11));
    __hv_line_f(&sLine_ishI1gPi, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_fFF6wSdp, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_G0tln4XA, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_rGxdkI0s, VIf(Bf10));
    __hv_line_f(&sLine_OWwE4qbb, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_raZvvW9o, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_58QEIvpx, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_i8MnBXhy, VIf(Bf10));
    __hv_line_f(&sLine_doflGaew, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_vQ3qLIBE, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_QqgroNRZ, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_eq4Qf41g, VIf(Bf10));
    __hv_varwrite_f(&sVarf_pMVu6uR5, VIf(Bf0));
    __hv_varwrite_f(&sVarf_lY5BOI3L, VIf(Bf1));
    __hv_varwrite_f(&sVarf_rpY57DEc, VIf(Bf2));
    sEnv_process(this, &sEnv_9gr0j1h1, VIf(Bf3), &sEnv_9gr0j1h1_sendMessage);
    sEnv_process(this, &sEnv_vLyDUOqV, VIf(I0), &sEnv_vLyDUOqV_sendMessage);
    __hv_line_f(&sLine_L8yYLnq8, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_T2oYDfrU, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_GQmLZRGZ, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_eog9agXk, VOf(Bf3));
    __hv_line_f(&sLine_kqBuZREP, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_UTvU3obp, VIf(Bf0));
    __hv_varwrite_f(&sVarf_eog9agXk, VIf(Bf4));
    __hv_varwrite_f(&sVarf_blylx15h, VIf(Bf5));
    __hv_varwrite_f(&sVarf_jElP9FdC, VIf(Bf6));
    __hv_varread_f(&sVarf_jElP9FdC, VOf(Bf6));
    __hv_line_f(&sLine_iknEXkul, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_wCc4Sm45, VIf(Bf4));
    __hv_varread_f(&sVarf_blylx15h, VOf(Bf4));
    __hv_line_f(&sLine_FaRx2ZOb, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_xPgze1ER, VIf(Bf4));
    __hv_varwrite_f(&sVarf_ZIsWwHFp, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Ex7myXRr, VIf(I1));
    __hv_varread_f(&sVarf_EcSP8n4B, VOf(Bf2));
    __hv_varread_f(&sVarf_uLpiYzYQ, VOf(Bf4));
    __hv_varread_f(&sVarf_dfM24tPD, VOf(Bf0));
    __hv_varread_f(&sVarf_pxDUPLQy, VOf(Bf5));
    __hv_varread_f(&sVarf_s23omfUJ, VOf(Bf3));
    __hv_varread_f(&sVarf_dABOo7FA, VOf(Bf6));
    __hv_varread_f(&sVarf_7mZ4V3aI, VOf(Bf1));
    __hv_varwrite_f(&sVarf_8BjOS2wi, VIf(I1));
    __hv_varread_f(&sVarf_acGQmIOZ, VOf(Bf10));
    __hv_line_f(&sLine_iGWpmTX6, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_28yt0Ppa, VOf(Bf7));
    __hv_line_f(&sLine_1EuQrMyW, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_HiILVQEo, VOf(Bf11));
    __hv_line_f(&sLine_nVZTVLz7, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_pxDUPLQy, VIf(Bf12));
    __hv_varread_f(&sVarf_8BjOS2wi, VOf(Bf12));
    __hv_line_f(&sLine_DwfYmObS, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_h606NhuY, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_NtyfU5bY, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_s23omfUJ, VIf(Bf9));
    __hv_line_f(&sLine_2jlbMQpQ, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_3jDLoquP, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_CNRF5SMp, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_dABOo7FA, VIf(Bf9));
    __hv_line_f(&sLine_v9wfl2CI, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_kOCgqA2u, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_1Bj9nx5T, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_7mZ4V3aI, VIf(Bf9));
    __hv_varwrite_f(&sVarf_acGQmIOZ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_28yt0Ppa, VIf(Bf4));
    __hv_varwrite_f(&sVarf_HiILVQEo, VIf(Bf0));
    sEnv_process(this, &sEnv_zWCxrp3f, VIf(Bf5), &sEnv_zWCxrp3f_sendMessage);
    sEnv_process(this, &sEnv_7LOlVo3c, VIf(I1), &sEnv_7LOlVo3c_sendMessage);
    __hv_line_f(&sLine_Dwleamw2, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_xDXGHvZ4, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_FcYiKPZ8, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_iK3NPcBa, VOf(Bf5));
    __hv_line_f(&sLine_WpbUbgIi, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_EcSP8n4B, VIf(Bf2));
    __hv_varwrite_f(&sVarf_iK3NPcBa, VIf(Bf3));
    __hv_varwrite_f(&sVarf_TumcM0tN, VIf(Bf6));
    __hv_varwrite_f(&sVarf_QgQ6ZKaA, VIf(Bf1));
    __hv_varread_f(&sVarf_QgQ6ZKaA, VOf(Bf1));
    __hv_line_f(&sLine_3AHwNz2U, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_dfM24tPD, VIf(Bf3));
    __hv_varread_f(&sVarf_TumcM0tN, VOf(Bf3));
    __hv_line_f(&sLine_HqUm03ih, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_uLpiYzYQ, VIf(Bf3));
    __hv_varwrite_f(&sVarf_UQQpvux3, VIf(Bf0));
    __hv_varread_f(&sVarf_Ex7myXRr, VOf(Bf0));
    __hv_line_f(&sLine_q9NEY9QL, VOf(Bf3));
    __hv_varread_f(&sVarf_UQQpvux3, VOf(Bf2));
    __hv_line_f(&sLine_uhNS3O2d, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_R2041KNk, VOf(Bf2));
    __hv_varread_f(&sVarf_ZIsWwHFp, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
